@@ -1,6 +1,6 @@
 pred.genv <- function(m, Xnew, Znew){
   if (is.null(m$ratio)) 
-    stop("The asymptotic distribution part of env is missing. Rerun env with asy = T")
+    stop("The asymptotic distribution part of genv is missing. Rerun genv with asy = T")
   r <- ncol(m$Sigma[[1]])
   n <- m$n
   ng <- m$ng
@@ -39,4 +39,4 @@ pred.genv <- function(m, Xnew, Znew){
   return(list(value = value, covMatrix.estm = covMatrix.estm, 
               SE.estm = SE.estm, covMatrix.pred = covMatrix.pred, SE.pred = SE.pred))
   
-}
\ No newline at end of file
+}
